@@ -183,6 +183,8 @@ class Battery(object):
 class StorageInputs(object):
     batteries: t.List[Battery]
     cycling_cost_adder: t.Optional[float] = 0
+    window: t.Optional[int] = opt_field()
+    step: t.Optional[int] = opt_field()
 
 
 
